==> haskell-libyaml-0.1.1.0-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-C3dIrZKrpe46xGKSQ8rtiw
key: libyaml-0.1.1.0-C3dIrZKrpe46xGKSQ8rtiw
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: cb32cddec2737c2c40a9a9bfa711b9c5
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-C3dIrZKrpe46xGKSQ8rtiw
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.1.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-DQc7lovHfuyAZxOkI8TGEm
key: libyaml-0.1.1.0-DQc7lovHfuyAZxOkI8TGEm
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: 44e8d7eab67f57c7b6ab63146b76d0b3
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-DQc7lovHfuyAZxOkI8TGEm
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
